@@ -247,11 +247,11 @@ mod tests {
 
     #[test]
     fn trust_location() -> Result<(), Error> {
-        let pem_dir = Path::new(concat!(env!("CARGO_MANIFEST_DIR"), "/../../../tests/pems"));
+        let pem_dir = Path::new(concat!(env!("CARGO_MANIFEST_DIR"), "/../certs"));
         let mut cert = pem_dir.to_path_buf();
-        cert.push("rsa_4096_sha512_client_cert.pem");
+        cert.push("cert.pem");
         let mut key = pem_dir.to_path_buf();
-        key.push("rsa_4096_sha512_client_key.pem");
+        key.push("key.pem");
 
         let mut builder = crate::config::Builder::new();
         builder.set_security_policy(&security::DEFAULT_TLS13)?;
@@ -269,11 +269,11 @@ mod tests {
     /// on OCSP explicitly still works when `trust_location()` is called.
     #[test]
     fn trust_location_does_not_change_ocsp_status() -> Result<(), Error> {
-        let pem_dir = Path::new(concat!(env!("CARGO_MANIFEST_DIR"), "/../../../tests/pems"));
+        let pem_dir = Path::new(concat!(env!("CARGO_MANIFEST_DIR"), "/../certs"));
         let mut cert = pem_dir.to_path_buf();
-        cert.push("rsa_4096_sha512_client_cert.pem");
+        cert.push("cert.pem");
         let mut key = pem_dir.to_path_buf();
-        key.push("rsa_4096_sha512_client_key.pem");
+        key.push("key.pem");
 
         const OCSP_IANA_EXTENSION_ID: u16 = 5;
 
@@ -618,8 +618,8 @@ mod tests {
             builder
                 .set_client_hello_callback(TestClientHelloHandler {})
                 .unwrap();
-            builder.load_pem(keypair.cert, keypair.key).unwrap();
-            builder.trust_pem(keypair.cert).unwrap();
+            builder.load_pem(keypair.cert(), keypair.key()).unwrap();
+            builder.trust_pem(keypair.cert()).unwrap();
             builder.build().unwrap()
         };
         let mut pair = TestPair::from_config(&config);
@@ -702,7 +702,7 @@ mod tests {
         let mut pair = TestPair::from_config(&config);
         drop(pair.client);
 
-        let mut client_tx_stream = pair.client_tx_stream.borrow_mut();
+        let mut client_tx_stream = pair.io.client_tx_stream.borrow_mut();
         client_tx_stream.write_all(SSLV2_CLIENT_HELLO_HEADER)?;
         client_tx_stream.write_all(SSLV2_CLIENT_HELLO_PREFIX)?;
         client_tx_stream.write_all(SSLV2_CLIENT_HELLO_CIPHER_SUITES)?;
