@@ -6,7 +6,7 @@ from constants import TRUST_STORE_BUNDLE, TRUST_STORE_TRUSTED_BUNDLE
 from configuration import PROTOCOLS
 from common import ProviderOptions, Ciphers, pq_enabled
 from fixtures import managed_process  # lgtm [py/unused-import]
-from global_flags import get_flag, is_criterion_on, S2N_FIPS_MODE, S2N_USE_CRITERION
+from global_flags import get_flag, S2N_FIPS_MODE
 from providers import Provider, S2N
 from test_pq_handshake import PQ_ENABLED_FLAG
 from utils import invalid_test_parameters, get_parameter_name, to_bytes
@@ -38,7 +38,8 @@ ENDPOINTS = [
     "www.github.com",
     "www.ibm.com",
     "www.microsoft.com",
-    "www.mozilla.org",
+    # https://github.com/aws/s2n-tls/issues/4879
+    # "www.mozilla.org",
     "www.netflix.com",
     "www.openssl.org",
     "www.samsung.com",
@@ -109,10 +110,6 @@ def test_well_known_endpoints(managed_process, protocol, endpoint, provider, cip
     if get_flag(S2N_FIPS_MODE) is True:
         client_options.trust_store = TRUST_STORE_TRUSTED_BUNDLE
 
-    # TODO: Understand the failure with criterion and this endpoint.
-    if is_criterion_on() and 'www.netflix.com' in endpoint:
-        pytest.skip()
-
     # expect_stderr=True because S2N sometimes receives OCSP responses:
     # https://github.com/aws/s2n-tls/blob/14ed186a13c1ffae7fbb036ed5d2849ce7c17403/bin/echo.c#L180-L184
     client = managed_process(provider, client_options,
