@@ -12,6 +12,12 @@
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
+
+#ifndef _S2N_PRELUDE_INCLUDED
+    /* make sure s2n_prelude.h is includes as part of the compiler flags, if not then fail the build */
+    #error "Expected s2n_prelude.h to be included as part of the compiler flags"
+#endif
+
 #define _GNU_SOURCE
 #include <ctype.h>
 #include <openssl/crypto.h>
